# Copyright (C) 2021 Emanuele Di Giacomo <emanuele@digiacomo.cc>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 2 of the License or (at your
# option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
__version__ = '0.4.3'
__author__ = "Emanuele Di Giacomo <emanuele@digiacomo.cc>"
__copyright__ = "Copyright (C) 2021 Emanuele Di Giacomo"
__license__ = "GPLv2+"

default_app_config = 'statusboard_notify.apps.StatusboardNotifyConfig'
